@@ -44,3 +44,17 @@ class HandlerTest(TestCase):
             call.inner(payload, command),
             call.post(payload, command),
         ])
+
+    def testHandlerInvokePostProcessorWithOrigPayloadNamedParamWhenTransformerGiven(self):
+        payload = {"foo": ["bar", "baz"]}
+        generator = Mock()
+
+        Handler(
+            lambda payload, command: None,
+            transformer=lambda input: {"input": [input]},
+            postProcessor=generator,
+        )(payload, "command.name")
+
+        generator.assert_has_calls([
+            call({"input": [payload]}, "command.name", payload)
+        ])
